MapLibrePlatform class abstract

Constructors

MapLibrePlatform()

Methods

addCircleLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
addFillExtrusionLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
addFillLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
addGeoJsonSource(String sourceId, Map<String, dynamic> geojson, {String? promoteId}) Future<void>
addHeatmapLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) Future<void>
addHillshadeLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) Future<void>
addImage(String name, Uint8List bytes, [bool sdf = false]) Future<void>
addImageSource(String imageSourceId, Uint8List bytes, LatLngQuad coordinates) Future<void>
addLayer(String imageLayerId, String imageSourceId, double? minzoom, double? maxzoom) Future<void>
addLayerBelow(String imageLayerId, String imageSourceId, String belowLayerId, double? minzoom, double? maxzoom) Future<void>
addLineLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
addRasterLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom}) Future<void>
addSource(String sourceId, SourceProperties properties) Future<void>
addSymbolLayer(String sourceId, String layerId, Map<String, dynamic> properties, {String? belowLayerId, String? sourceLayer, double? minzoom, double? maxzoom, dynamic filter, required bool enableInteraction}) Future<void>
animateCamera(CameraUpdate cameraUpdate, {Duration? duration}) Future<bool?>
buildView(Map<String, dynamic> creationParams, OnPlatformViewCreatedCallback onPlatformViewCreated, Set<Factory<OneSequenceGestureRecognizer>>? gestureRecognizers) Widget
clearAmbientCache() Future
dispose() → void
easeCamera(CameraUpdate cameraUpdate, {Duration? duration, CameraAnimationInterpolation? interpolation}) Future<bool>
Animates the camera to a new position with a specified duration and interpolation.
editGeoJsonSource(String id, String data) Future<bool>
Edits a GeoJSON source with new data.
editGeoJsonUrl(String id, String url) Future<bool>
Edits a GeoJSON source with a new URL.
forceOnlineMode() Future<void>
Forces the map to use online mode (disables offline mode).
forceResizeWebMap() → void
getCustomHeaders() Future<Map<String, String>>
Returns the custom HTTP headers currently set on this map instance.
getFeatureState(String sourceId, String featureId, {String? sourceLayer}) Future<Map<String, dynamic>?>
getFilter(String layerId) Future
getLayerIds() Future<List>
getLayerVisibility(String layerId) Future<bool?>
Returns the visibility of a layer. Returns true if visible, false if hidden, null if layer not found.
getMetersPerPixelAtLatitude(double latitude) Future<double>
getSourceIds() Future<List>
getStyle() Future<String?>
Gets the current map style as JSON string.
getTelemetryEnabled() Future<bool>
getVisibleRegion() Future<LatLngBounds>
initPlatform(int id) Future<void>
invalidateAmbientCache() Future
matchMapLanguageWithDeviceDefault() Future<void>
moveCamera(CameraUpdate cameraUpdate) Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryCameraPosition() Future<CameraPosition?>
Queries the current camera position.
queryRenderedFeatures(Point<double> point, List<String> layerIds, List<Object>? filter) Future<List>
queryRenderedFeaturesInRect(Rect rect, List<String> layerIds, String? filter) Future<List>
querySourceFeatures(String sourceId, String? sourceLayerId, List<Object>? filter) Future<List>
removeFeatureState(String sourceId, {String? featureId, String? stateKey, String? sourceLayer}) Future<void>
removeLayer(String imageLayerId) Future<void>
removeSource(String sourceId) Future<void>
requestMyLocationLatLng() Future<LatLng?>
resizeWebMap() → void
setCameraBounds({required double west, required double north, required double south, required double east, required int padding}) Future<void>
setCustomHeaders(Map<String, String> headers, List<String> filter) Future<void>
Sets custom HTTP headers for requests made by this map instance.
setFeatureForGeoJsonSource(String sourceId, Map<String, dynamic> geojsonFeature) Future<void>
setFeatureState(String sourceId, String featureId, Map<String, dynamic> state, {String? sourceLayer}) Future<void>
setFilter(String layerId, dynamic filter) Future<void>
setGeoJsonSource(String sourceId, Map<String, dynamic> geojson) Future<void>
setLayerFilter(String layerId, String filter) Future<bool>
Sets a filter for a layer.
setLayerProperties(String layerId, Map<String, dynamic> properties) Future<void>
setLayerVisibility(String layerId, bool visible) Future<void>
setMapLanguage(String language) Future<void>
setMaximumFps(int fps) Future<void>
Performance Controls Sets the maximum frames per second for the map rendering.
setStyle(String styleString) Future<void>
Method to set style string A MapLibre GL style document defining the map's appearance. The style document specification is at https://maplibre.org/maplibre-style-spec. A short introduction can be found in the documentation of the maplibre_gl library. The styleString supports following formats:
setTelemetryEnabled(bool enabled) Future<void>
setWebMapToCustomSize(Size size) Future<Size>
Sets the web map to a custom size for rendering. Returns the previous/initial size of the web map before this change.
takeSnapshot({int? width, int? height}) Future<Uint8List>
Takes a screenshot of the current map view as PNG bytes. Returns a Uint8List containing the PNG image data. Supported on all platforms (Android, iOS, Web).
toLatLng(Point<num> screenLocation) Future<LatLng>
toScreenLocation(LatLng latLng) Future<Point<num>>
toScreenLocationBatch(Iterable<LatLng> latLngs) Future<List<Point<num>>>
toString() String
A string representation of this object.
inherited
updateContentInsets(EdgeInsets insets, bool animated) Future<void>
updateImageSource(String imageSourceId, Uint8List? bytes, LatLngQuad? coordinates) Future<void>
updateMapOptions(Map<String, dynamic> optionsUpdate) Future<CameraPosition?>
updateMyLocationTrackingMode(MyLocationTrackingMode myLocationTrackingMode) Future<void>
waitUntilMapIsIdleAfterMovement() Future<void>
Waits until the map is idle after camera movement.
waitUntilMapTilesAreLoaded() Future<void>
Waits until all visible map tiles are loaded.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

createInstance MapLibrePlatform Function()
The default instance of MapLibrePlatform to use.
getter/setter pair