PolylineData class

Lightweight data class for polylines / routes. Replaces google_maps_flutter Polyline with a plain data holder.

Constructors

PolylineData({required String id, required List<LatLng> points, Color color = const Color(0xFF6CA6F7), int width = 10, bool visible = true, int zIndex = 0, bool isDashed = false, Color? borderColor})

Properties

borderColor Color?
Color of the border (outline) drawn beneath the main line. When non-null, a wider line in this color is drawn first to create a border effect on both sides of the main route line.
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isDashed bool
final
points List<LatLng>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
final
width int
final
zIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited