ShareMapLayerIds class
Pre-defined layer IDs built into the ShareMap style JSON.
Use these constants to dynamically show, hide, or restyle layers on the map
using controller.setLayerVisibility(layerId, 'visible' | 'none') or raw paint/layout operations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
bySource
→ const Map<
String, List< String> > - Map of all layers grouped by their source ID.
- Layers belonging to the landmarks 'sharemap-landmarks' source (1 layer).
- Layers belonging to the business overlay 'sharemaplayers' source (42 layers).
- Layers belonging to the base 'sharemaptiles' source (114 layers).
-
vietnamSovereignty
→ const List<
String> - Layers belonging to the sovereignty labels 'vietnam-sovereignty' source (1 layer).